netapp_ontap.models.vdi_on_san API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.vdi_on_san`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VdiOnSanSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VdiOnSan object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `desktops GET POST PATCH`

    The desktops field of the vdi_on_san.

  `hypervisor GET POST`

    The name of the hypervisor hosting the application.

    Valid choices:

    - hyper_v
    - vmware
    - xen
  `igroup_name GET POST PATCH`

    The name of the initiator group through which the contents of this application will be accessed. Modification of this parameter is a disruptive operation. All LUNs in the application component will be unmapped from the current igroup and re-mapped to the new igroup.

  `new_igroups POST PATCH`

    The list of initiator groups to create.

  `protection_type GET POST PATCH`

    The protection_type field of the vdi_on_san.